const ticketStatus = ['rule', 'people'] as const;

export type Ticket = {
  id: string;
  type: string;
  title: string;
  description: string;
  status: (typeof ticketStatus)[number];
  price: string;
  createdAt: string;
  updatedAt: string;
  uid: string;
};

// 票务类型列表
const ticketTypes = ['演唱会', '话剧', '电影', '展览', '体育赛事'];

// 生成随机日期字符串（过去30天内）
const generateRandomDate = () => {
  const now = new Date();
  const pastDays = Math.floor(Math.random() * 30);
  const date = new Date(now.getTime() - pastDays * 24 * 60 * 60 * 1000);
  return date.toISOString();
};

// 生成随机价格（100-2000元）
const generateRandomPrice = () => {
  return `¥${Math.floor(Math.random() * 1900 + 100)}`;
};

// 生成随机ID
const generateRandomId = () => {
  return Math.random().toString(36).substring(2, 10);
};

// 生成20条模拟数据
export const mockTickets: Ticket[] = Array.from({ length: 20 }, (_, index) => {
  const createdAt = generateRandomDate();
  const updatedAt = new Date(new Date(createdAt).getTime() + Math.random() * 24 * 60 * 60 * 1000).toISOString();
  const type = ticketTypes[Math.floor(Math.random() * ticketTypes.length)];
  const status = ticketStatus[Math.floor(Math.random() * ticketStatus.length)];
  
  return {
    id: `ticket-${generateRandomId()}`,
    type,
    title: `${type}票务-${index + 1}`,
    description: `这是一张${type}的门票，编号为${index + 1}，提供优质观演体验。`,
    status,
    price: generateRandomPrice(),
    createdAt,
    updatedAt,
    uid: `user-${generateRandomId()}`,
  };
});

// 导出默认数据
export default mockTickets;