import { DataTypes, Model, UUIDV4 } from 'sequelize';
import { sequelize } from '@/modules/sequelize.ts';

// 定义票据状态类型
const ticketStatus = ['rule', 'people'] as const;
export type Ticket = {
  id: string;
  type: string;
  title: string;
  description: string;
  status: (typeof ticketStatus)[number];
  price: string;
  createdAt: string;
  updatedAt: string;
  uid: string;
};

// 创建Ticket模型类
export class TicketModel extends Model<Ticket> implements Ticket {
  declare id: string;
  declare type: string;
  declare title: string;
  declare description: string;
  declare status: (typeof ticketStatus)[number];
  declare price: string;
  declare createdAt: string;
  declare updatedAt: string;
  declare uid: string;
}

// 初始化模型
TicketModel.init(
  {
    id: {
      type: DataTypes.UUID,
      defaultValue: UUIDV4,
      primaryKey: true,
    },
    type: {
      type: DataTypes.STRING,
      allowNull: false,
    },
    title: {
      type: DataTypes.STRING,
      allowNull: false,
    },
    description: {
      type: DataTypes.TEXT,
      allowNull: true,
    },
    status: {
      type: DataTypes.STRING,
      allowNull: false,
      defaultValue: 'rule',
    },
    price: {
      type: DataTypes.STRING,
      allowNull: false,
    },
    uid: {
      type: DataTypes.STRING,
      allowNull: false,
    },
    createdAt: {
      type: DataTypes.DATE,
      allowNull: false,
    },
    updatedAt: {
      type: DataTypes.DATE,
      allowNull: false,
    },
  },
  {
    sequelize,
    tableName: 'tickets',
    timestamps: true,
  },
);

await TicketModel.sync({ alter: true })